from wsgitemplates.middleware_template import Middleware
from wsgitemplates.composite_template import Composite
from wsgitemplates.endpoint_template import Endpoint as EndPoint
from wsgitemplates.package import Package